@@ -1,6 +1,8 @@
-#line 1 "inc/Module/Install/Makefile.pm - /usr/pkg/lib/perl5/site_perl/5.8.0/Module/Install/Makefile.pm"
+#line 1 "inc/Module/Install/Makefile.pm - /usr/local/lib/perl5/site_perl/5.8.5/Module/Install/Makefile.pm"
 package Module::Install::Makefile;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use Module::Install::Base;
+@ISA = qw(Module::Install::Base);
 
 $VERSION = '0.01';
 
@@ -154,4 +156,4 @@ sub postamble {
 
 __END__
 
-#line 286
+#line 288
