@@ -1,14 +1,12 @@
-#line 1 "inc/Module/Install/Metadata.pm - /usr/pkg/lib/perl5/site_perl/5.8.0/Module/Install/Metadata.pm"
+#line 1 "inc/Module/Install/Metadata.pm - /usr/local/lib/perl5/site_perl/5.8.5/Module/Install/Metadata.pm"
 package Module::Install::Metadata;
 
-use strict 'vars';
 use Module::Install::Base;
+@ISA = qw{Module::Install::Base};
 
-use vars qw($VERSION @ISA);
-BEGIN {
-    $VERSION = '0.06';
-    @ISA     = 'Module::Install::Base';
-}
+$VERSION = '0.06';
+
+use strict 'vars';
 
 my @scalar_keys = qw{
     name module_name abstract author version license
